# ZynkLite

[![PyPI - Version](https://img.shields.io/pypi/v/zynk-lite.svg)](https://pypi.org/project/zynk-lite)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/zynk-lite.svg)](https://pypi.org/project/zynk-lite)
[![License: GPLv3](https://img.shields.io/badge/License-GPLv3-blue.svg)](https://www.gnu.org/licenses/gpl-3.0)
-----

## Table of Contents

- [Installation](#installation)
- [License](#license)

## Installation

```bash
pip install zynk-lite
```

## Documentation
[Documentation](https://github.com/Guille-ux/ZynkLite)

## License

`zynk-lite` is distributed under the terms of the [GPLv3](https://spdx.org/licenses/GPL-3.0-or-later.html) license. license.
